@@ -11,6 +11,7 @@ pub struct Arguments {
         help = "Ignore every line that matches any of these provided regexes. For example, to ignore the imports and package declarations in Java code  `--ignore-line-regex '^import ' '^package '`."
     )]
     pub ignore_line_regex: Vec<String>,
+
     #[structopt(
         long,
         help = "Ignore every file that matches any of these provided regexes. For example, to all XML and CSV files  `--ignore-file-regex '[.]xml$' '[.]csv$'`."
@@ -23,4 +24,10 @@ pub struct Arguments {
         default_value = "3"
     )]
     pub minimum_successive_lines: usize,
+
+    #[structopt(
+        long,
+        help = "Output all the duplicates information as single line JSON. So it can easily be stored, ingested and processed by other programs."
+    )]
+    pub json: bool,
 }
