@@ -5,7 +5,6 @@ extern crate pretty_env_logger;
 use structopt::StructOpt;
 
 mod cli;
-mod directory_reader;
 mod duplicate_detection;
 mod hashing_utilities;
 mod model;
@@ -19,8 +18,7 @@ fn main() {
     let arguments = cli::Arguments::from_args();
     debug!("The command line arguments provided are {:?}.", arguments);
 
-    let raw_files =
-        crate::directory_reader::get_files_in_current_directory(arguments.ignore_file_regex);
+    let raw_files = crate::model::raw_file::get_raw_files(arguments.ignore_file_regex);
     let indexed_files =
         crate::model::indexed_file::to_indexed_files(arguments.ignore_line_regex, raw_files);
     let hashed_files = crate::model::hashed_file::to_hashed_files(&indexed_files);
