@@ -1,10 +1,11 @@
 use crate::model::line_range::LineRange;
+use serde::Serialize;
 
 use super::*;
 
 pub type Duplicates = Vec<Duplicate>;
 
-#[derive(serde::Serialize, PartialOrd, PartialEq, Ord, Eq)]
+#[derive(Serialize, PartialOrd, PartialEq, Ord, Eq)]
 pub struct Duplicate {
     pub file_1: Filename,
     pub file_1_line_range: LineRange,
