@@ -1,5 +1,3 @@
-#[cfg(test)]
-use serde::{Serialize, Serializer};
 use std::collections::{HashMap, HashSet};
 
 use crate::model::indexed_file::*;
@@ -10,50 +8,22 @@ pub type HashedFiles = Vec<HashedFile>;
 pub type HashToLineNumbers = HashMap<blake3::Hash, HashSet<LineNumber>>;
 pub type LineNumberToHash = HashMap<LineNumber, blake3::Hash>;
 
-#[cfg_attr(test, derive(Serialize))]
+#[cfg_attr(test, derive(serde::Serialize))]
 pub struct HashedFile {
     pub filename: Filename,
     pub number_of_lines: LineNumber,
-    #[cfg_attr(test, serde(serialize_with = "ordered_hash_to_line_numbers"))]
+    #[cfg_attr(
+        test,
+        serde(serialize_with = "tests::ordered_serialization::ordered_hash_to_line_numbers")
+    )]
     pub hash_to_line_numbers: HashToLineNumbers,
-    #[cfg_attr(test, serde(serialize_with = "ordered_line_number_to_hash"))]
+    #[cfg_attr(
+        test,
+        serde(serialize_with = "tests::ordered_serialization::ordered_line_number_to_hash")
+    )]
     pub line_number_to_hash: LineNumberToHash,
 }
 
-#[cfg(test)]
-fn ordered_hash_to_line_numbers<S>(
-    value: &HashToLineNumbers,
-    serializer: S,
-) -> Result<S::Ok, S::Error>
-where
-    S: Serializer,
-{
-    let ordered: std::collections::BTreeMap<String, Vec<&usize>> = value
-        .iter()
-        .map(|(k, v)| {
-            let mut vector = v.iter().collect::<Vec<_>>();
-            vector.sort();
-            (k.to_hex().to_string(), vector)
-        })
-        .collect();
-    ordered.serialize(serializer)
-}
-
-#[cfg(test)]
-fn ordered_line_number_to_hash<S>(
-    value: &LineNumberToHash,
-    serializer: S,
-) -> Result<S::Ok, S::Error>
-where
-    S: Serializer,
-{
-    let ordered: std::collections::BTreeMap<&usize, String> = value
-        .iter()
-        .map(|(k, v)| (k, v.to_hex().to_string()))
-        .collect();
-    ordered.serialize(serializer)
-}
-
 impl HashedFile {
     pub fn new(filename: &str, indexed_file: &IndexedFile) -> Self {
         let mut hash_to_line_numbers = HashMap::new();
